Minigpu class final

Controls the initialization and destruction of the minigpu context.

Constructors

Minigpu()

Properties

hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBuffer(int bufferSize, BufferDataType dataType) Buffer
Creates a buffer.
createComputeShader() ComputeShader
Creates a compute shader.
destroy() Future<void>
Destroys the minigpu context.
getOrCreateCachedShader(String shaderCode) ComputeShader
Internal method to get or create cached shader by code
init() Future<void>
Initializes the minigpu context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited