ComputeShader class final
A compute shader.
- Available extensions
Constructors
- ComputeShader(PlatformComputeShader shader)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shaderCode ↔ String?
-
getter/setter pair
Methods
-
destroy(
) → void - Destroys the compute shader.
-
dispatch(
int groupsX, int groupsY, int groupsZ) → Future< void> - Dispatches the specified kernel with the given work group counts.
-
hasKernel(
) → bool - Checks if the shader has a kernel loaded.
-
loadKernelAsset(
String assetPath) → Future< void> -
Available on ComputeShader, provided by the LoadKernels extension
Loads a kernel from an asset file. -
loadKernelFile(
String filePath) → Future< void> -
Available on ComputeShader, provided by the LoadKernels extension
Loads a kernel from a file. -
loadKernelString(
String kernelString) → void - Loads a kernel string into the shader.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBuffer(
String tag, Buffer buffer) → void - Sets a buffer for the specified kernel and tag.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited